#' @keywords internal
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
#' @importFrom lifecycle deprecate_soft
## usethis namespace: end
NULL


# \lifecycle{experimental}
# \lifecycle{maturing}
# \lifecycle{stable}
# \lifecycle{superseded}
# \lifecycle{questioning}
# \lifecycle{soft-deprecated}
# \lifecycle{deprecated}
# \lifecycle{defunct}
# \lifecycle{archived}
